==> mdm-rpc-0.1.25-sources.jar: com/chinayanghe/msp/mdm/vo/position/PositionInformationVo.java <==
package com.chinayanghe.msp.mdm.vo.position;

import com.chinayanghe.msp.mdm.vo.role.RoleBasicInformationVo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by danDy on 2017/4/27.
 */
public class PositionInformationVo implements Serializable {
    private static final long serialVersionUID = 6179866819073364397L;
    //岗位编码
    private String positionCode;
    //岗位名称
    private  String positionName;
    //岗位上人员编码（取岗位上面关联的人，在全营销是账号）
    private String userName;
    //岗位启用状态
    private Integer enableStatus;
    //岗位所属组织编码
    private String orgCode;
    //岗位类别编码
    private String categoryCode;
    //是否占编(Y:占编,N:不占编)
    private String organization;
    //是否为所属组织的管理者(Y:是,N:否)
    private String administration;
    //岗位类别名称
    private String categoryName;
    //业务组编码
    private String businessGroup;
    //创建人
    private String createName;
    //创建时间
    private Date createDate;
    //最新更新人
    private String updateName;
    //最新更新时间
    private Date updateDate;

    //组织层级
    private String orgHierarchyCode;
    private String orgHierarchyName;
    /**
     * 岗位对应多角色
     * @return
     */
    private List<RoleBasicInformationVo> roleBasicInformationVoList ;

    public String getPositionCode() {
        return positionCode;
    }

    public void setPositionCode(String positionCode) {
        this.positionCode = positionCode;
    }

    public String getPositionName() {
        return positionName;
    }

    public void setPositionName(String positionName) {
        this.positionName = positionName;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getCategoryCode() {
        return categoryCode;
    }

    public void setCategoryCode(String categoryCode) {
        this.categoryCode = categoryCode;
    }

    public String getOrganization() {
        return organization;
    }

    public void setOrganization(String organization) {
        this.organization = organization;
    }

    public String getAdministration() {
        return administration;
    }

    public void setAdministration(String administration) {
        this.administration = administration;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public String getBusinessGroup() {
        return businessGroup;
    }

    public void setBusinessGroup(String businessGroup) {
        this.businessGroup = businessGroup;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public List<RoleBasicInformationVo> getRoleBasicInformationVoList() {
        return roleBasicInformationVoList;
    }

    public void setRoleBasicInformationVoList(List<RoleBasicInformationVo> roleBasicInformationVoList) {
        this.roleBasicInformationVoList = roleBasicInformationVoList;
    }

    public String getOrgHierarchyCode() {
        return orgHierarchyCode;
    }

    public void setOrgHierarchyCode(String orgHierarchyCode) {
        this.orgHierarchyCode = orgHierarchyCode;
    }

    public String getOrgHierarchyName() {
        return orgHierarchyName;
    }

    public void setOrgHierarchyName(String orgHierarchyName) {
        this.orgHierarchyName = orgHierarchyName;
    }
}

==> mdm-rpc-0.1.30-sources.jar: com/chinayanghe/msp/mdm/vo/position/PositionInformationVo.java <==
package com.chinayanghe.msp.mdm.vo.position;

import com.chinayanghe.msp.mdm.vo.role.RoleBasicInformationVo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by danDy on 2017/4/27.
 */
public class PositionInformationVo implements Serializable {
    private static final long serialVersionUID = 6179866819073364397L;
    //岗位编码
    private String positionCode;
    //岗位名称
    private  String positionName;
    //岗位上人员编码（取岗位上面关联的人，在全营销是账号）
    private String userName;
    //岗位启用状态
    private Integer enableStatus;
    //岗位所属组织编码
    private String orgCode;
    //岗位类别编码
    private String categoryCode;
    //是否占编(Y:占编,N:不占编)
    private String organization;
    //是否为所属组织的管理者(Y:是,N:否)
    private String administration;
    //岗位类别名称
    private String categoryName;
    //业务组编码
    private String businessGroup;
    //创建人
    private String createName;
    //创建时间
    private Date createDate;
    //最新更新人
    private String updateName;
    //最新更新时间
    private Date updateDate;

    //组织层级
    private String orgHierarchyCode;
    private String orgHierarchyName;
    /**
     * 岗位对应多角色
     * @return
     */
    private List<RoleBasicInformationVo> roleBasicInformationVoList ;
    /**
     * 是否sfa移动访销岗位
     */
    private Boolean sfaPosition;
    public String getPositionCode() {
        return positionCode;
    }

    public void setPositionCode(String positionCode) {
        this.positionCode = positionCode;
    }

    public String getPositionName() {
        return positionName;
    }

    public void setPositionName(String positionName) {
        this.positionName = positionName;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getCategoryCode() {
        return categoryCode;
    }

    public void setCategoryCode(String categoryCode) {
        this.categoryCode = categoryCode;
    }

    public String getOrganization() {
        return organization;
    }

    public void setOrganization(String organization) {
        this.organization = organization;
    }

    public String getAdministration() {
        return administration;
    }

    public void setAdministration(String administration) {
        this.administration = administration;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public String getBusinessGroup() {
        return businessGroup;
    }

    public void setBusinessGroup(String businessGroup) {
        this.businessGroup = businessGroup;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public List<RoleBasicInformationVo> getRoleBasicInformationVoList() {
        return roleBasicInformationVoList;
    }

    public void setRoleBasicInformationVoList(List<RoleBasicInformationVo> roleBasicInformationVoList) {
        this.roleBasicInformationVoList = roleBasicInformationVoList;
    }

    public String getOrgHierarchyCode() {
        return orgHierarchyCode;
    }

    public void setOrgHierarchyCode(String orgHierarchyCode) {
        this.orgHierarchyCode = orgHierarchyCode;
    }

    public String getOrgHierarchyName() {
        return orgHierarchyName;
    }

    public void setOrgHierarchyName(String orgHierarchyName) {
        this.orgHierarchyName = orgHierarchyName;
    }

    public Boolean getSfaPosition() {
        return sfaPosition;
    }

    public void setSfaPosition(Boolean sfaPosition) {
        this.sfaPosition = sfaPosition;
    }
}
